Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/xamarin/macdoc.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'AppDelegate.cs')
-rw-r--r--AppDelegate.cs7
1 files changed, 4 insertions, 3 deletions
diff --git a/AppDelegate.cs b/AppDelegate.cs
index 2a43a8c..f612061 100644
--- a/AppDelegate.cs
+++ b/AppDelegate.cs
@@ -65,10 +65,11 @@ namespace macdoc
ExtractImages ();
controller = new MonodocDocumentController ();
// Some UI feature we use rely on Lion, so special case it
try {
var version = new NSDictionary ("/System/Library/CoreServices/SystemVersion.plist");
- isOnLion = version.ObjectForKey (new NSString ("ProductVersion")).ToString ().StartsWith ("10.7");
+ var osxVersion = Version.Parse (version.ObjectForKey (new NSString ("ProductVersion")).ToString ());
+ isOnLion = osxVersion.Major == 10 && osxVersion.Minor >= 7;
} catch {}
// Load documentation
@@ -171,7 +172,7 @@ namespace macdoc
private set;
}
- public static bool IsOnLion {
+ public static bool IsOnLionOrBetter {
get {
return isOnLion;
}
@@ -65,10 +65,11 @@ namespace macdoc
ExtractImages ();
controller = new MonodocDocumentController ();
- // Some UI feature we use rely on Lion, so special case it
+ // Some UI feature we use rely on Lion or better, so special case it
try {
var version = new NSDictionary ("/System/Library/CoreServices/SystemVersion.plist");